@@ -1,3 +1,6 @@
+# Copyright © 2022 Intel Corporation
+#
+# SPDX-License-Identifier: MIT
 import copy
 import warnings
 
@@ -411,6 +414,13 @@ class Progress(ApiObject):
   remaining_budget = Field(float)
 
 
+class RunsProgress(ApiObject):
+  active_run_count = Field(int)
+  finished_run_count = Field(int)
+  total_run_count = Field(int)
+  remaining_budget = Field(float)
+
+
 class Suggestion(ApiObject):
   assignments = Field(Assignments)
   created = Field(int)
@@ -482,6 +492,26 @@ class Experiment(ApiObject):
   user = Field(str)
 
 
+class AIExperiment(ApiObject):
+  budget = Field(float)
+  client = Field(str)
+  conditionals = Field(ListOf(Conditional))
+  created = Field(int)
+  id = Field(str)
+  linear_constraints = Field(ListOf(LinearConstraint))
+  metadata = Field(Metadata)
+  metrics = Field(ListOf(Metric))
+  name = Field(str)
+  num_solutions = Field(int)
+  parallel_bandwidth = Field(int)
+  parameters = Field(ListOf(Parameter))
+  progress = Field(RunsProgress)
+  project = Field(str)
+  state = Field(str)
+  updated = Field(int)
+  user = Field(str)
+
+
 class Token(ApiObject):
   all_experiments = Field(bool)
   client = Field(str)
